@@ -1,5 +1,5 @@
-__version__ = "1.3.1"
-__date__ = "May 11, 2013"
+__version__ = "1.3.2"
+__date__ = "Oct 31, 2013"
 
 from subprocess import Popen, PIPE, call
 from threading import Thread
